'use strict';
const stackTrace = require('stack-trace');
const Error = require('../core/error');

// The purpose of this module is for checking the compliance of the modules required by the client code.

// Check vulnerable instantiation of Hashids module
module.exports = (exports, name) => {
  class HashidsPatch extends exports {

    //new Hashids(salt)
    constructor() {
      let checkDefaultOrShortSalt = (args) => args &&
        (args.indexOf('salt' != -1) || // Contains the word salt, or
          args.length <= 16)           // is shorter than 16 characters

      let salt = arguments[0];

      if (checkDefaultOrShortSalt(salt)) {
        let moduleName = `module.${name}`;
        let message = `Contains default or short salt '${salt}'`;

        let complianceError = new Error()
          .setCode(1)
          .setDescription(`Non-Compliance for ${moduleName}: ${message}`)
          .setType("compliance");

        let trace = stackTrace.get()[1];
        if (trace) {
          complianceError
            .setLocation(trace.getFileName())
            .setLine(trace.getLineNumber());
        }

        bitSensor.apply(datapoint => {
          datapoint.addError(complianceError);
        });
      }

      super(arguments)
    }
  }

  return HashidsPatch;
};