'use strict';
const stackTrace = require('stack-trace');
const Error = require('../core/error');

// The purpose of this module is for tracing sql query executed by the client code.
module.exports = (exports, name) => {
  if (!exports.version || !exports.version.startsWith('4.'))
    return exports

  class SequelizePatch extends exports {

    // query("CREATE TABLE...", {})
    query(sql, options) {

      let sqlTrace = new Error()
        .setCode(1)
        .setDescription(`${sql}`)
        .setType("sqltrace");

      let trace = stackTrace.get()[1];
      if (trace) {
        sqlTrace
          .setLocation(trace.getFileName())
          .setLine(trace.getLineNumber());
      }

      bitSensor.apply(datapoint => {
        datapoint.addError(sqlTrace);
      });

      return super.query(sql, options)
    }
  }

  return SequelizePatch;
}