var expect = require('chai').expect;
require('../core/init');
var cls = require('continuation-local-storage');

describe('BitSensor', () => {
  beforeEach(() => {
    cls.destroyNamespace('bitsensor');
    cls.createNamespace('bitsensor');
  });

  describe('#initialized', () => {
    bitSensor.runSession(() => {
      it('must not be initialized initially', () => {
        expect(bitSensor.isInitialized()).to.be.false;
      });
    });
  });
  describe('#isDisabled', () => {
    bitSensor.runSession(() => {
      it('must be 0 initially', () => {
        expect(bitSensor.isDisabled).to.be.null;
      });
      it('must equal to 1 when call setDisabled()', () => {
        bitSensor.setDisabled();
        expect(bitSensor.isDisabled).to.equal(1);
      });
      it('must be disabled', () => {
        expect(bitSensor.hasBeenDisabled()).to.be.true;
      });
      it('must equal to 0 when call setEnabled()', () => {
        bitSensor.setEnabled();
        expect(bitSensor.isDisabled).to.equal(0);
      });
      it('must be enabled', () => {
        expect(bitSensor.hasBeenDisabled()).to.be.false;
      });
    });
  });
  describe('#isHandlingRequest', () => {
    it('must be undefined initially', () => {
      expect(bitSensor.isHandingRequest).to.be.undefined;
    });

    it('must change when start and stop tracing', () => {
      bitSensor.runSession(() => {
        expect(bitSensor.isHandlingRequest).to.equal(1);
        bitSensor.runSession(() => {
          expect(bitSensor.isHandlingRequest).to.equal(2);
        });
        expect(bitSensor.isHandlingRequest).to.equal(1);
      });
    });
  });
  describe('#clear', () => {
    it('must be set initially', () => {
      bitSensor.runSession(() => {
        expect(bitSensor.getDatapoint()).to.not.be.undefined;
        expect(bitSensor.isHandlingRequest).to.not.be.undefined;
        expect(bitSensor.isDisabled).to.not.be.undefined;
        bitSensor.clear();
        expect(bitSensor.getDatapoint()).to.be.null;
        expect(bitSensor.isHandlingRequest).to.be.null;
        expect(bitSensor.isDisabled).to.be.null;
      });
    });
  });
  describe('#apply', () => {

  });
});
