const expect = require('chai').expect;
const Datapoint = require('./../core/datapoint');
const Error = require('./../core/error');

describe('Datapoint', function () {
  let datapoint;
  beforeEach(() => {
    datapoint = new Datapoint();
  });

  describe('#putContext', function () {
    it('must not put invalid key', () => {
      datapoint.putContext(null, 'value');
      datapoint.putContext(undefined, 'value');
      datapoint.putContext(1, 'value');
      datapoint.putContext(' ', 'value');
      datapoint.putContext('', 'value');
      expect(datapoint.context).to.be.empty;
    });

    it('must not put invalid value', () => {
      datapoint.putContext('key', null);
      datapoint.putContext('key', undefined);
      datapoint.putContext('key', 1);
      datapoint.putContext('key', ' ');
      datapoint.putContext('key', '');
      expect(datapoint.context).to.be.empty;
    });

    it('must put context key', () => {
      datapoint.putContext('key', 'without_dot');
      datapoint.putContext('key.subkey', 'with_dot');
      expect(datapoint.context).to.include({key: 'without_dot', 'key.subkey': 'with_dot'});
    })
  });

  describe('#addError', function () {
    it('must not add null Error', () => {
      datapoint.addError(null);
      expect(datapoint.errors).to.be.empty;
    });

    it('must add error', () => {
      const error = new Error()
        .setCode(1)
        .setDescription("test")
        .setLocation("main.js")
        .setLine(2);
      datapoint.addError(error);
      expect(datapoint.errors).to.include(error);
    })
  });
});
